---

slug: /vector-search-faq
---

# Vector search FAQs

This topic describes some common issues that may occur when using vector search, as well as their causes and solutions.

## Must all rows in a vector column have the same data dimensionality?

Yes. A data dimensionality must be specified when a vector column is defined, and the dimensionality must be verified when vector data is written into the column.

## What is the maximum number of rows of vector data that can be written?

Unlimited. It depends on the database memory resources.

## How do I create an index on a vector with more than 4096 dimensions?

You need to compress the data to within 4096 dimensions before creating an index.